@@ -477,6 +477,14 @@
 </context>
 <context>
     <name>MainWindow</name>
+    <message>
+        <source>This is the first launch of the program.
+By default, only Moscow map is available.
+Want to download more cities?</source>
+        <translation>Este es el primer lanzamiento del programa.
+Por defecto, sólo está disponible el mapa de Moscú.
+¿Quieres descargar más ciudades?</translation>
+    </message>
     <message>
         <location filename="../../ui/mainwindow.ui" line="148"/>
         <location filename="../../ui/mainwindow.ui" line="565"/>
@@ -709,9 +717,9 @@
         <source>1. Wait until loaded site...
 2. Select map
 3. Save file map here:</source>
-        <translation>1. Espere hasta que el sitio carga ...
-2. Seleccione el mapa
-3. Guardar archivo de mapa aquí:</translation>
+        <translation>1. Espere hasta que el sitio está cargado...
+2. Seleccione un mapa
+3. Guardar un archivo de mapa aquí:</translation>
     </message>
 </context>
 <context>
@@ -739,7 +747,7 @@
     <message>
         <location filename="../../ui/settings.ui" line="212"/>
         <source>Font...</source>
-        <translation>Tipo de letra</translation>
+        <translation>Fuente...</translation>
     </message>
     <message>
         <location filename="../../ui/settings.ui" line="219"/>
@@ -803,8 +811,8 @@
     </message>
     <message>
         <location filename="../../ui/settings.ui" line="524"/>
-        <source>Caching graphics</source>
-        <translation>Gráficos de almacenamiento en caché</translation>
+        <source>Cache graphics to raster</source>
+        <translation>Gráficos de caché de mapa de bits</translation>
     </message>
     <message>
         <location filename="../../ui/settings.ui" line="534"/>
