@@ -2,6 +2,33 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="ru">
 <defaultcodec>windows-1251</defaultcodec>
+<context>
+    <name>QSoftKeyManager</name>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation>Выбрать</translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation>Готово</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Параметры</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отмена</translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation>Выход</translation>
+    </message>
+</context>
 <context>
     <name>QColorDialog</name>
     <message>
@@ -87,6 +114,14 @@
         <source>Close</source>
         <translation>Закрыть</translation>
     </message>
+    <message>
+        <source>&amp;Yes</source>
+        <translation>&amp;Да</translation>
+    </message>
+    <message>
+        <source>&amp;No</source>
+        <translation>&amp;Нет</translation>
+    </message>
 </context>
 <context>
     <name>QFontDatabase</name>
@@ -308,14 +343,19 @@
 </context>
 <context>
     <name>MainWindow</name>
+    <message>
+        <location line="-737"/>
+        <source>Loading...</source>
+        <translation>Загрузка...</translation>
+    </message>
     <message>
         <location filename="../../ui/mainwindow.ui" line="+148"/>
-        <location line="+447"/>
+        <location line="+420"/>
         <source>Find</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location line="-354"/>
+        <location line="-357"/>
         <source>Waiting time</source>
         <translation>Время ожидания</translation>
     </message>
@@ -330,7 +370,7 @@
         <translation>Описание</translation>
     </message>
     <message>
-        <location line="+127"/>
+        <location line="+130"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
@@ -340,12 +380,11 @@
         <translation>&amp;Настройки</translation>
     </message>
     <message>
-        <location line="+4"/>
         <source>Language</source>
         <translation>Язык</translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+19"/>
         <source>&amp;View</source>
         <translation>&amp;Вид</translation>
     </message>
@@ -472,17 +511,17 @@
         <translation>Транслитерация</translation>
     </message>
     <message>
-        <location line="-352"/>
+        <location line="-355"/>
         <source>Routes</source>
         <translation>Маршруты</translation>
     </message>
     <message>
-        <location line="+332"/>
+        <location line="+335"/>
         <source>About...</source>
         <translation>О программе...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="+439"/>
+        <location filename="../../src/mainwindow.cpp" line="+524"/>
         <source>Open file</source>
         <translation>Открыть файл</translation>
     </message>
@@ -536,38 +575,55 @@
         <translation>ОК</translation>
     </message>
     <message>
-        <location line="+210"/>
+        <location line="+219"/>
         <source>All</source>
         <translation>Все</translation>
     </message>
     <message>
-        <location line="-406"/>
-        <location line="+406"/>
+        <location line="-425"/>
+        <location line="+425"/>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location line="-404"/>
+        <location line="-422"/>
         <source>Start</source>
         <translation>Начальная</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Finish</source>
         <translation>Конечная</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>Default start</source>
         <translation>Начальная по умолчанию</translation>
     </message>
     <message>
-        <location line="+407"/>
+        <location line="+39"/>
+        <source>This is the first launch of the program.
+Want to download more cities?</source>
+        <translation>Это первый запуск программы.
+Желаете загрузить больше городов?</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Да</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>&amp;No</source>
+        <translation>&amp;Нет</translation>
+    </message>
+    <message>
+        <location line="+381"/>
         <source>Categories</source>
         <translation>Категории</translation>
     </message>
     <message>
-        <location line="+228"/>
+        <location line="+253"/>
         <source>Add maps</source>
         <translation>Добавление карты</translation>
     </message>
@@ -636,12 +692,11 @@
         <translation>Масштаб интерфейса</translation>
     </message>
     <message>
-        <location line="+114"/>
         <source>Caching graphics</source>
         <translation>Кешировать графику</translation>
     </message>
     <message>
-        <location line="+53"/>
+        <location line="+167"/>
         <source>Simple graphics for transfers*</source>
         <translation>Упрощённая графика для переходов*</translation>
     </message>
@@ -650,7 +705,7 @@
         <translation>Фон</translation>
     </message>
     <message>
-        <location filename="../../src/settings.cpp" line="+45"/>
+        <location filename="../../src/settings.cpp" line="+59"/>
         <source>Color...</source>
         <translation>Цвет...</translation>
     </message>
@@ -694,7 +749,12 @@
         <translation>Производительность</translation>
     </message>
     <message>
-        <location line="+37"/>
+        <location line="+27"/>
+        <source>Cache graphics to raster</source>
+        <translation>Кешировать графику в растр</translation>
+    </message>
+    <message>
+        <location line="+10"/>
         <source>Show time to the stations</source>
         <translation>Показывать время до станций</translation>
     </message>
@@ -753,7 +813,7 @@
         <translation>Конечная</translation>
     </message>
     <message>
-        <location filename="../../src/mapview/mapview.cpp" line="+357"/>
+        <location filename="../../src/mapview/mapview.cpp" line="+397"/>
         <source>Day</source>
         <translation>День</translation>
     </message>
@@ -773,14 +833,14 @@
         <translation>Час-пик</translation>
     </message>
     <message>
-        <location line="+115"/>
+        <location line="+106"/>
         <source>Cannot open file mapping:
 %1</source>
         <translation>Невозможно открыть файл карты:
 %1</translation>
     </message>
     <message>
-        <location line="+1093"/>
+        <location line="+1168"/>
         <source>line</source>
         <translation>линия</translation>
     </message>
@@ -800,7 +860,7 @@
         <translation>Переход на станцию:</translation>
     </message>
     <message>
-        <location line="+262"/>
+        <location line="+270"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
@@ -817,7 +877,7 @@
         <translation>Переход на станцию:</translation>
     </message>
     <message>
-        <location line="-257"/>
+        <location line="-265"/>
         <source>Final station:</source>
         <translation>Конечная станция:</translation>
     </message>
@@ -941,12 +1001,12 @@
 <context>
     <name>About</name>
     <message>
-        <location filename="../../src/about.h" line="+27"/>
+        <location filename="../../src/about.h" line="+28"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="+40"/>
         <source>Unknown author</source>
         <translation>Неизвестный автор</translation>
     </message>
