@@ -2,15 +2,23 @@
 
 #include "completer.h"
 #include "mapview/mapview.h"
+//#include "flickcharm.h"
 
-TCompleter::TCompleter(TMapView *map,QLineEdit *parent)
+TCompleter::TCompleter(TMapView *mapView,QLineEdit *parent)
  : QObject(parent), editor(parent)
 {
+ map=mapView;
  list=map->getNamesAndColors();
+ MobileVersion=map->config.MobileVersion;
+
+ indName=0;
+ indColor=1;
+ if(MobileVersion) qSwap(indName,indColor);
+
  popup = new QTreeWidget(parent);
+ popup->setStyleSheet("show-decoration-selected:1;");
  popup->setWindowFlags(Qt::Popup);
  popup->setFocusPolicy(Qt::NoFocus);
- popup->setFocusProxy(parent);
  popup->setMouseTracking(true);
 
  popup->setColumnCount(2);
@@ -22,6 +30,17 @@ TCompleter::TCompleter(TMapView *map,QLineEdit *parent)
  popup->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
  popup->header()->hide();
  popup->installEventFilter(this);
+// if(MobileVersion)
+// {
+//  popup->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//  //popup->setColumnWidth(1,editor->width());
+// }
+// else
+   popup->setFocusProxy(parent);
+
+
+ //FlickCharm *fcharm = new FlickCharm(popup);
+ //fcharm->activateOn(popup);
 
  connect(popup, SIGNAL(itemClicked(QTreeWidgetItem*,int)),SLOT(doneCompletion()));
 
@@ -94,36 +113,34 @@ void TCompleter::showCompletion(QList< QPair<QString,QColor> > list)
 
 // const QPalette &pal = editor->palette();
 // QColor color = pal.color(QPalette::Disabled, QPalette::WindowText);
-
  popup->setUpdatesEnabled(false);
  popup->clear();
  for (int i = 0; i < list.count(); ++i)
  {
   QTreeWidgetItem * item;
   item = new QTreeWidgetItem(popup);
-  item->setText(0, list.at(i).first);
+  item->setText(indName, list.at(i).first);
 #ifdef Q_WS_MAEMO_5
-  item->setText(1,"=");
-  item->setFont(1,QFont("",QFont().pointSize()*2,87));
-  item->setTextColor(1, list.at(i).second);
+  item->setText(indColor,"=");
+  item->setFont(indColor,QFont("",QFont().pointSize()*2,87));
+  item->setTextColor(indColor, list.at(i).second);
 #endif
-  item->setBackgroundColor(1,list.at(i).second);
-  //item->setIcon(1,); //icon with transparent
-  item->setTextAlignment(1, Qt::AlignCenter);
+  item->setBackgroundColor(indColor,list.at(i).second);
+  //item->setIcon(indColor,); //icon with transparent
+  item->setTextAlignment(indColor, Qt::AlignCenter);
  }
- popup->setCurrentItem(popup->topLevelItem(0));
- popup->resizeColumnToContents(0);
- popup->setColumnWidth(1,15);
- //popup->resizeColumnToContents(1);
+ popup->setCurrentItem(popup->topLevelItem(0),(MobileVersion ? 1:0));
+ popup->resizeColumnToContents(indName);
  popup->adjustSize();
+ popup->setColumnWidth(indColor,editor->height()/(MobileVersion ? 2:1));
  popup->setUpdatesEnabled(true);
 
- int h = popup->sizeHintForRow(0) * qMin(7, list.count()) + 3;
- popup->resize(popup->columnWidth(0)+40, h);
-
+ int h = popup->sizeHintForRow(0) * qMin((MobileVersion ? 4:7), list.count()) + 3;
+ //when with style// popup->move(editor->mapToGlobal(QPoint(editor->height()/2, editor->height()-1)));
  popup->move(editor->mapToGlobal(QPoint(0, editor->height())));
- popup->setFocus();
+ if(!MobileVersion) popup->setFocus();
  popup->show();
+ popup->resize(popup->columnWidth(indName)+editor->height()+( popup->verticalScrollBar()->isVisible() ? popup->verticalScrollBar()->width():0), h);
  popup->repaint();
 }
 
@@ -134,12 +151,16 @@ void TCompleter::doneCompletion()
  editor->setFocus();
  QTreeWidgetItem *item = popup->currentItem();
  if (item)
- {
-  int i=idFiltred.at(popup->currentIndex().row());
-  editor->setText(item->text(0));
+ { 
+  int id=idFiltred.at(popup->currentIndex().row());
+  editor->setText(item->text(indName));
   QMetaObject::invokeMethod(editor, "returnPressed");
-  emit doneCompletionByID(i);
+  emit doneCompletionByID(id);
+  idFiltred.clear();
+  idFiltred << id;
+  map->findedNodesToFront(idFiltred);
  }
+
 }
 
 void TCompleter::autoSuggest()
