@@ -25,17 +25,29 @@
 #include "mobileui.h"
 #include "flickcharm.h"
 
-QString VERSION=" 0.5.2";
+//#ifdef MEEGO_EDITION_HARMATTAN
+//#include <QX11Info>
+//#include <X11/Xatom.h>
+//#include <X11/Xlib.h>
+//#endif
+
+
+#ifdef Q_OS_SYMBIAN
+QString VERSION="0.5.7";
+#endif
+
 QString URL_MAPS="http://pmetro.su/Maps.html";
 QString URL_TRANSLATE="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
 
-char ICONSIZE=24; // begin size 100% scale
+bool LITE=0;
+int ICONSIZE=24; // begin size 100% scale
 QString TOOLBAR_STYLE=
-  "QToolButton,QToolButton:pressed,QLabel,QLineEdit{border:2px solid grey;border-radius:5px;background-color:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 rgba(255,255,255,60%));} "
-  "QToolButton{height:%1px;width:%1px;background-color:transparent;margin-top:4px;margin-left:4px;} "
-  "QToolButton:pressed{margin-top:5px;margin-left:5px;} "
-  "QLabel{color:black;font-weight:bold;padding:2px;} "
-  "QLineEdit{height:%1px;font-weight:bold;margin-top:2px;margin-left:2px;}";
+  "QToolButton,QToolButton:pressed,QLabel,QLineEdit{border:%7px solid grey;border-radius:%2px;background-color:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 rgba(255,255,255,60%));} "
+  "QToolButton{height:%1px;width:%1px;background-color:transparent;margin-top:%6px;margin-left:%6px;} "
+  "QToolButton:pressed{margin-top:%5px;margin-left:%5px;} "
+  "QLabel{color:black;font-weight:bold;padding:%7px;margin-left:%5px;} "
+  "QLineEdit{color:black;border-radius:%2px;height:%1px;font-weight:bold;padding-left:%6px;} "
+  "Sizes{size: 1%; size/2: %2; size/4: %3; size/6: %4; size/8: %5; size/10: %6; size/12: %7; }";
 
 MainWindow *mainWnd;
 
@@ -53,15 +65,19 @@ QVector <QString> IniGroupStr;
 QVector <QString> IniKeyStr;
 
 MainWindow::MainWindow(QWidget *parent) :
-    QMainWindow(parent),map(NULL),SettingWindow(NULL),ui(new Ui::MainWindow),Completer(NULL)
+    QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),Completer(NULL)
 {
-#if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_OS_ANDROID)
+#if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN) || defined(Q_OS_ANDROID)
  MobileVersion=1;
+ qApp->setOverrideCursor(Qt::BlankCursor);
 #else
  MobileVersion=0;
+ LITE=0;
 #endif
 
  //MobileVersion=1;
+ //setAttribute(Qt::WA_AutoOrientation);
+ setAttribute(Qt::WA_AcceptTouchEvents);
  codePage = QTextCodec::codecForName("windows-1251");
  mainWnd=this;
  IniGroupStr << "MapView"<<"Main"<<"Other";
@@ -71,10 +87,11 @@ MainWindow::MainWindow(QWidget *parent) :
               "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale";
 
 
- Config.appFont=qApp->font();
+ Config.appUiScale=1;
  appPath=qApp->applicationDirPath()+"/";
  appConfigFile=cachePath="";
-#ifdef Q_OS_LINUX
+
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
  QString home=qgetenv("HOME");
  appPath="/usr/share/qmetro/";
  if(!home.isEmpty())
@@ -83,23 +100,43 @@ MainWindow::MainWindow(QWidget *parent) :
   appConfigFile=home+"/.config/qMetro/config.conf";
  }
 #endif
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+ #if defined(Q_WS_MAEMO_5)
  setAttribute(Qt::WA_Maemo5AutoOrientation);
  setAttribute(Qt::WA_Maemo5StackedWindow);
  setAttribute(Qt::WA_Maemo5NonComposited);
+ ICONSIZE=64;
+ #else
+ // MOBILE NONNATIVE INTERFACE
+ Config.appUiScale=2.5;
+ qApp->setStyle("cleanlooks");
+ MobileVersion=2;
+
+ // Orientation - set manually to portrait
+// #ifdef Q_WS_X11
+// WId id = this->winId();
+// Display *display = QX11Info::display();
+// if (!display) return;
+// Atom orientationAngleAtom = XInternAtom(display, "_MEEGOTOUCH_ORIENTATION_ANGLE", False);
+// XChangeProperty(display, id, orientationAngleAtom, XA_CARDINAL, 32, PropModeReplace, (unsigned char*)270, 1);
+// #endif
+ #endif
  appPath="/home/user/MyDocs/Data/qMetro/";
  cachePath=appPath+".cache/";
  appConfigFile="/home/user/.config/qMetro/config.conf";
- ICONSIZE=64;
 #endif
 #ifdef Q_OS_ANDROID
  appPath="/sdcard/Android/data/qMetro/";
  cachePath=appPath+".cache/";
- setScaleForUi(2.6);
+
+ // MOBILE NONNATIVE INTERFACE
+ Config.appUiScale=2.5;
+ qApp->setStyle("cleanlooks");
+ MobileVersion=2;
 #endif
 #ifdef Q_OS_SYMBIAN
  appPath="e:/Data/qMetro/";
- ICONSIZE=48;
+ ICONSIZE=56;
 #endif
 
  if(appConfigFile.isEmpty()) appConfigFile=appPath+"config.ini";
@@ -110,30 +147,54 @@ MainWindow::MainWindow(QWidget *parent) :
  ini->setIniCodec(codePage);
  QString key;
  ini->beginGroup("Main");
+ if(VERSION!=ini->value("Version").toString())
+ {
+  ini->remove(IniKeyStr[ikWUiScale]);
+  ini->remove("Styles");
+  removeDir(cachePath);
+ }
+
+ Config.mapKineticScrollCheck=0; // its work so bad...
  Config.locale=ini->value("Locale","").toString();
  Config.dockWidth=ini->value("DockWidth",0).toInt();
- key="WindowFullScreen";
+ Config.appUiScale=ini->value(IniKeyStr[ikWUiScale],Config.appUiScale).toReal();
+
+ key="Mobile";
+ if(ini->contains(key)) MobileVersion=ini->value(key).toInt();
+ key=IniKeyStr[ikWFullScreen];
+ if(MobileVersion && !ini->contains(key)) ini->setValue(key,1);
  Config.appFullscreen=ini->value(key,0).toBool();
  key="MapZoomFactor";
- Config.mapZoomFactor=ini->value(key).toFloat();
+ Config.mapZoomFactor=ini->value(key).toReal();
  Config.mapZoomFactorCheck=ini->contains(key);
  key="MapPosition";
  Config.mapPosition=ini->value(key).toPoint();
  Config.mapPositionCheck=ini->contains(key);
- key="Mobile";
- if(ini->contains(key)) MobileVersion=ini->value(key).toInt();
- key="Font";
- if(ini->contains(key))
- {
-  Config.appFont.fromString(ini->value(key).toString());
-  qApp->setFont(Config.appFont);
- }
+
+ Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
+ Config.appFirstStart=!ini->contains(IniKeyStr[ikMLastFile]);
  TOOLBAR_STYLE=ini->value("Styles",TOOLBAR_STYLE).toString();
  if(Config.locale.isEmpty()) Config.locale=QLocale::system().name().section("_",0,0);
+ if(Config.locale=="uk") Config.locale="ru";
  toggleLang(Config.locale);
+
  ui->setupUi(this); // UI #############################
+ //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
+ showPageLoading();
  restoreState(QByteArray::fromHex(ini->value("WindowState").toByteArray()));
- if(!MobileVersion)
+
+ if(MobileVersion)
+ {
+  ui->menuFile->removeAction(ui->mExit);
+  ui->menuFile->removeAction(ui->mClear);
+  removeToolBar(ui->toolBar);
+
+  // set UI size for device
+  Config.appIconSize=ICONSIZE=qMin(qApp->desktop()->width(),qApp->desktop()->height()) / 6.5;
+  Config.appFont.setPixelSize(ICONSIZE/2.5);
+  Config.appUiScale=1;
+ }
+ else
  {
   key="WindowGeometry";
   if(ini->contains(key))
@@ -147,35 +208,54 @@ MainWindow::MainWindow(QWidget *parent) :
    setWindowState(Qt::WindowMaximized);
   }
  }
+
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
+ ui->menuHelp->setIcon(QIcon());
+#endif
+#ifdef Q_OS_SYMBIAN
+ ui->menuFile->menuAction()->setVisible(0);
+ ui->menuHelp->menuAction()->setVisible(0);
+ menuBar()->addActions(ui->menuFile->actions());
+ menuBar()->addMenu(ui->menuSetting);
+ menuBar()->addActions(ui->menuHelp->actions());
+#endif
+
+#ifdef QT_NO_DEBUG
+ ui->menuView->menuAction()->setVisible(0);
+ ui->menuInfo->menuAction()->setVisible(0);
+ //ui->menuSetting->menuAction()->setVisible(0);
+ //ui->menuHelp->addAction(ui->menuLanguage->menuAction());
+#endif
+
+if(LITE)
+{
+ ui->menuSetting->menuAction()->setVisible(0);
+ ui->mSave->setVisible(0);
+}
+
+ qApp->setFont(Config.appFont);
+ setWindowTitle(windowTitle()+(MobileVersion ? QString(""):QString(" ")+VERSION));
+
+ if(Config.appFullscreen) //AppConfig.value(igMain).value(ikWFullScreen).toInt()
+      toFullScreen();
+ else (MobileVersion ? showMaximized():show());
+ qApp->processEvents();
+
  ui->mSaveScale->setChecked(Config.mapZoomFactorCheck);
  ui->mSavePosition->setChecked(Config.mapPositionCheck);
  if(!Config.dockWidth) Config.dockWidth=ui->dock->width();
  ui->dock->setVisible(0);
  //ui->eSearch->setText(tr("Find"));
  //ui->eSearch->installEventFilter(this);
- ini->endGroup();
-
- setWindowTitle(windowTitle()+VERSION);
 
  map = new TMapView(appPath,cachePath);
  map->config.MobileVersion=MobileVersion;
  map->config.locale=Config.locale;
-
  connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
- if(!MobileVersion)
+ if(!MobileVersion) // show description panel
    connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool)));
  connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
 
- //map->config.enableCaching=1;
- Config.mapKineticScrollCheck=0;
- if(Config.mapKineticScrollCheck)
- {
-  charm.activateOn(map);
-  connect(&charm,SIGNAL(started()),map,SLOT(mapStartDragging()));
-  connect(&charm,SIGNAL(finished()),map,SLOT(mapStopDragging()));
- }
-
-
  ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
 
  if(!MobileVersion)
@@ -188,7 +268,7 @@ MainWindow::MainWindow(QWidget *parent) :
   EditLayout->addWidget(ui->bClear);
   ui->eSearch->setLayout(EditLayout);
 
-  QSplitter *splitter = new QSplitter;
+  QSplitter *splitter = new QSplitter();
   splitter->addWidget(ui->dock);
 //  QLabel *LoadingLabel =new QLabel(this);
 //  QMovie *LoadingMovie =new QMovie(":/img/loading.gif");
@@ -200,7 +280,8 @@ MainWindow::MainWindow(QWidget *parent) :
   splitter->setStretchFactor(1, 1);
   splitter->setChildrenCollapsible(0);
   splitter->setOpaqueResize(0);
-  setCentralWidget(splitter);
+  ui->pMap->layout()->addWidget(splitter);
+  //setCentralWidget(splitter);
 
   QLabel *label = new QLabel("");
   label->setMinimumWidth(0);
@@ -212,37 +293,19 @@ MainWindow::MainWindow(QWidget *parent) :
  }else
  {
   resize(qApp->desktop()->width(),qApp->desktop()->height());
-  centralWidget()->layout()->addWidget(map);
-  mUi = new TMobileUi(this,map);
+  ui->pMap->layout()->addWidget(map);
+  //centralWidget()->layout()->addWidget(map);
   //setCentralWidget(map);
+  mUi = new TMobileUi(this,map);
  }
-
-#ifdef Q_OS_LINUX
- ui->menuHelp->setIcon(QIcon());
-#endif
-#ifdef Q_OS_SYMBIAN
- // Remove context menu from all widgets
- QWidgetList widgets=QApplication::allWidgets();
- QWidget* w=0;
- foreach(w,widgets) w->setContextMenuPolicy(Qt::NoContextMenu);
-#endif
-
-#ifdef QT_NO_DEBUG
- ui->menuView->menuAction()->setVisible(0);
- ui->menuInfo->menuAction()->setVisible(0);
- //ui->menuSetting->menuAction()->setVisible(0);
- //ui->menuHelp->addAction(ui->menuLanguage->menuAction());
-#endif
-
+ setScaleForUi(Config.appUiScale);
 
  // apply config
  map->show();
- if(Config.appFullscreen) //AppConfig.value(igMain).value(ikWFullScreen).toInt()
-      ui->mFullScreen->setChecked(1);
- else (MobileVersion ? showMaximized():show());
 
  if(windowState()==Qt::WindowMaximized) // Under linux that need for correct FitInView
   map->resize(qApp->desktop()->availableGeometry().width(),qApp->desktop()->availableGeometry().height()-(height()-map->height())-20);
+
  loadSettings();
 
  if(Config.mapZoomFactorCheck) // first
@@ -265,20 +328,24 @@ MainWindow::MainWindow(QWidget *parent) :
  connect(ui->mZoomOut,SIGNAL(triggered()),map,SLOT(zoomOut()));
  connect(ui->mFit,SIGNAL(triggered()),map,SLOT(fitMap()));
 
- map->nodePopup = new QMenu(this);
- map->nodePopup->addAction(new QAction(QIcon(":/img/dialog-information.png"),tr("Information"),this));
- map->nodePopup->addSeparator();
- map->nodePopup->addAction(tr("Start"));
- map->nodePopup->addAction(tr("Finish"));
- map->nodePopup->addSeparator();
- map->nodePopup->addAction(tr("Default start"));
- map->nodePopup->actions().at(5)->setCheckable(1);
- connect(map->nodePopup, SIGNAL(aboutToShow()),this, SLOT(checkNodeDefault()));
- connect(map->nodePopup->actions().at(0), SIGNAL(triggered()),this, SLOT(nodeInformation()));
- connect(map->nodePopup->actions().at(2),SIGNAL(triggered()),map,SLOT(setNodeBegin()));
- connect(map->nodePopup->actions().at(3),SIGNAL(triggered()),map,SLOT(setNodeEnd()));
- connect(map->nodePopup->actions().at(5),SIGNAL(triggered(bool)),this,SLOT(setNodeDefault(bool)));
-
+ if(!LITE)
+ {
+  map->nodePopup = new QMenu(this);
+  map->nodePopup->addAction(new QAction(QIcon(":/img/dialog-information.png"),tr("Information"),this));
+  connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1), SIGNAL(triggered()),this, SLOT(nodeInformation()));
+  map->nodePopup->addSeparator();
+  map->nodePopup->addAction(tr("Start"));
+  connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1),SIGNAL(triggered()),map,SLOT(setNodeBegin()));
+  map->nodePopup->addAction(tr("Finish"));
+  connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1),SIGNAL(triggered()),map,SLOT(setNodeEnd()));
+  map->nodePopup->addSeparator();
+  map->nodePopup->addAction(tr("Default start"));
+  map->nodePopup->actions().at(map->nodePopup->actions().count()-1)->setCheckable(1);
+  connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1),SIGNAL(triggered(bool)),this,SLOT(setNodeDefault(bool)));
+  //need add QSignalMapper because dont know index
+  connect(map->nodePopup, SIGNAL(aboutToShow()),this, SLOT(checkNodeDefault()));
+  map->nodePopup->show(); map->nodePopup->hide(); // for initialize position
+ }
  if(map->nodeByID.count()) Completer= new TCompleter(map,ui->eSearch);
 
  installEventFilter(this);
@@ -306,6 +373,27 @@ MainWindow::MainWindow(QWidget *parent) :
  }
  if(MobileVersion) toggleLang(Config.locale);
  loadNodeDefault();
+
+ showPageMap();
+ if(Config.appFirstStart)
+ {
+  ui->mSaveScale->setChecked(1);
+  ui->mSavePosition->setChecked(1);
+  if(QMessageBox::question(this,windowTitle(),
+                        tr("This is the first launch of the program.\n"
+                           "Want to download more cities?"),QMessageBox::Yes|QMessageBox::No)==QMessageBox::Yes)
+  {
+   on_mAddMap_triggered();
+  }
+ }
+
+#ifdef Q_OS_SYMBIAN
+ // Remove context menu from all widgets ("Actions")
+ QWidgetList widgets=QApplication::allWidgets();
+ foreach(QWidget* w,widgets) w->setContextMenuPolicy(Qt::NoContextMenu);
+#endif
+
+ ini->endGroup();
 }
 
 MainWindow::~MainWindow()
@@ -329,7 +417,10 @@ void MainWindow::setNodeDefault(bool checked,TMapNode *Node)
   map->setNodeBegin(Node);
  }
  else
+ {
+  Config.mapDefaultStationID=-1;
   ini.remove(map->params.mapName);
+ }
  ini.endGroup();
 }
 void MainWindow::loadNodeDefault()
@@ -353,7 +444,14 @@ void MainWindow::loadNodeDefault()
 }
 void MainWindow::checkNodeDefault()
 {
- map->nodePopup->actions().at(5)->setChecked((map->nodeClick->ID==Config.mapDefaultStationID));
+ char first=0;
+#ifdef Q_OS_SYMBIAN
+ first=2;
+#endif
+ map->nodePopup->actions().at(first)->setEnabled(map->nodeClick->HasInfo);
+ map->nodePopup->actions().at(first)->setText(map->nodeClick->DisplayName+"...");
+ map->nodePopup->actions().at(map->nodePopup->actions().count()-1)->setChecked((map->nodeClick->ID==Config.mapDefaultStationID));
+ qApp->processEvents();
 }
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *e)
@@ -364,7 +462,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
  case QEvent::LanguageChange:
   {
    ui->retranslateUi(this);
-   if(SettingWindow) SettingWindow->ui->retranslateUi(SettingWindow);
+   if(SettingsWindow) SettingsWindow->ui->retranslateUi(SettingsWindow);
 #ifdef Q_WS_MAEMO_5
    ui->mPreference->setText(ui->menuSetting->title());
 #endif
@@ -391,10 +489,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
     map->clearTrack();
    }
    if(key==Qt::Key_F1) on_mAbout_triggered();
-   if(key==Qt::Key_F11)
-   {
-    ui->mFullScreen->setChecked(windowState()!=Qt::WindowFullScreen);
-   }
+   if(key==Qt::Key_F11) ui->mFullScreen->setChecked(windowState()!=Qt::WindowFullScreen);
    QString char_key=event->text().simplified();
    if(!ui->mFind->isChecked() && !char_key.isEmpty())//((key>=Qt::Key_A && key<=Qt::Key_Z)||(key>=Qt::Key_0 && key<=Qt::Key_9)) )
    {
@@ -411,14 +506,14 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
 
  if (obj == ui->eSearch && e->type()==QEvent::FocusIn)
  {
-  qDebug("QEvent::FocusIn event intercepted");
+  //qDebug("QEvent::FocusIn event intercepted");
   ((QLineEdit *)obj)->selectAll();
   return 0;
  }
  else
   if (obj == ui->eSearch && e->type()==QEvent::FocusOut)
   {
-  qDebug("QEvent::FocusOut event intercepted");
+  //qDebug("QEvent::FocusOut event intercepted");
   return 0;
  }
 
@@ -451,16 +546,23 @@ void MainWindow::on_mOpen_triggered()
    }
   }
 
- QString fileName = QFileDialog::getOpenFileName(this,
+ QString fileName = QFileDialog::getOpenFileName(0,
             tr("Open file"),MapPath,QString("%1 pMetro (*.pmz)").arg(tr("Map")),0,options);
 
  if (fileName.isEmpty()) return;
 
+ showPageLoading();
+ qApp->processEvents();
+
 //#ifndef QT_NO_CURSOR
 // QApplication::setOverrideCursor(Qt::WaitCursor);
 //#endif
 
 //testTimer.start();
+ QString TempCache=fileName.section('/', -1 );
+ TempCache=cachePath+TempCache.left(TempCache.indexOf("."))+"/";
+ QFile::remove(TempCache+".cache");
+ QFile::remove(TempCache+".info");
  if(Completer) delete Completer;
  map->loadMap(fileName);
  map->fitMap();
@@ -472,6 +574,7 @@ void MainWindow::on_mOpen_triggered()
 //#ifndef QT_NO_CURSOR
 // QApplication::restoreOverrideCursor();
 //#endif
+ showPageMap();
 }
 
 void MainWindow::on_mSave_triggered()
@@ -517,8 +620,12 @@ void MainWindow::on_bClear_clicked()
 {
  map->clearTrack();
  ui->eSearch->clear();
- ui->eSearch->setFocus();
- ui->cbDelay->setCurrentIndex(0);
+ if(!MobileVersion)
+ {
+  ui->eSearch->setFocus();
+  ui->cbDelay->setCurrentIndex(0);
+ }
+ else ui->mFind->setChecked(0);
 }
 
 void MainWindow::setDelayNames(QStringList list)
@@ -530,29 +637,49 @@ void MainWindow::setDelayNames(QStringList list)
 
 void MainWindow::on_mAbout_triggered()
 {
- About *a=new About(this);
- //if(MobileVersion) a->showMaximized(); else
- a->exec();
+ About *a=new About(0);
+ if(MobileVersion)
+ {
+   toFullScreen();
+   ui->stackMain->addWidget(a);
+   ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
+   //a->showFullScreen();
+ }
+ else a->exec();
 }
 
 void MainWindow::on_mPreference_triggered()
 {
- if(!SettingWindow)
+ if(!SettingsWindow)
  {
-  SettingWindow = new Settings(this);
+  SettingsWindow = new Settings(this);
 
 #ifdef Q_WS_MAEMO_5
-  SettingWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
-  SettingWindow->setWindowFlags(Qt::Window);
-  SettingWindow->setAttribute(Qt::WA_Maemo5AutoOrientation);
+  SettingsWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+  SettingsWindow->setWindowFlags(Qt::Window);
+  SettingsWindow->setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
  }
 
- SettingWindow->loadSettings(AppConfig);
+ //SettingWindow->loadSettingsToUi(AppConfig);
 
  if(MobileVersion)
-      SettingWindow->showMaximized();
- else SettingWindow->show();
+ {
+#ifndef Q_WS_MAEMO_5
+  connect(SettingsWindow,SIGNAL(showed()),this,SLOT(toFullScreen()));
+  connect(SettingsWindow,SIGNAL(closed()),this,SLOT(showPageMap()));
+  connect(SettingsWindow,SIGNAL(closed()),SettingsWindow,SLOT(close()));
+  ui->stackMain->addWidget(SettingsWindow);
+  ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
+#else
+  SettingsWindow->show();
+#endif
+
+
+ //      MobileVersion==2 ? SettingWindow->showFullScreen():SettingWindow->showMaximized();
+ }
+ else
+  SettingsWindow->show();
 }
 
 void MainWindow::toggleLang(QString locale)
@@ -575,6 +702,12 @@ void MainWindow::toggleLang(QString locale)
 void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
 {
  QTextBrowser *TextEdit=new QTextBrowser();
+ if(mainWnd->MobileVersion)
+ {
+  QFont TempFont=qApp->font();
+  TempFont.setPixelSize(TempFont.pixelSize()/1.3);
+  TextEdit->setFont(TempFont);
+ }
 
 #ifndef Q_WS_MAEMO_5
  FlickCharm *fcharm = new FlickCharm(TextEdit);
@@ -603,10 +736,31 @@ void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
 
 void MainWindow::nodeInformation()
 {
- if(!map->nodeClick) return;
-
+ if(!map->nodeClick && !map->nodeBegin) return;
+ if((MobileVersion && !map->nodeClick) || qobject_cast<QToolButton*>(sender())) map->nodeClick=map->nodeBegin;
+ //qDebug() << sender();
 //testTimer.start();
- Details *DetailsWindow = new Details(this);
+
+ Details *DetailsWindow = new Details();
+
+
+ if(MobileVersion)
+ {
+  QString style="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b></tr></table>";
+  showPageLoading();
+  qApp->processEvents();
+  QFont TempFont=qApp->font();
+  TempFont.setPixelSize(TempFont.pixelSize()/1.2);
+  DetailsWindow->ui->labelNodeName->setText(style.arg(map->nodeClick->Route->color.name()).arg(map->nodeClick->DisplayName));
+  DetailsWindow->ui->labelNodeName->setFont(TempFont);
+  DetailsWindow->ui->labelNodeName->setVisible(1);
+  DetailsWindow->setWindowTitle(map->nodeClick->DisplayName);
+ }else
+ {
+  DetailsWindow->ui->labelNodeName->setVisible(0);
+  DetailsWindow->setWindowTitle(DetailsWindow->windowTitle()+" "+map->nodeClick->DisplayName);
+  DetailsWindow->resize(640,480);
+ }
 
 #ifdef Q_WS_MAEMO_5
  DetailsWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -614,9 +768,6 @@ void MainWindow::nodeInformation()
  DetailsWindow->setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
 
-
- DetailsWindow->setWindowTitle((MobileVersion ? "":DetailsWindow->windowTitle()+" ")+map->nodeClick->DisplayName);
- DetailsWindow->resize(640,480);
  map->loadNodeInfo(map->nodeClick);
 
  TMapView *MapScheme;
@@ -634,23 +785,19 @@ void MainWindow::nodeInformation()
     layout = new QVBoxLayout;
     layout->setMargin(2);
     MapScheme = new TMapView(appPath,cachePath);
+
+    MapScheme->setParent(DetailsWindow);
     MapScheme->state.mapLoaded=0;
     MapScheme->config=map->config;
-    MapScheme->setAlignment(Qt::AlignCenter);
+    //MapScheme->setAlignment(Qt::AlignCenter);
+    //MapScheme->setTransformationAnchor(AnchorUnderMouse);
     MapScheme->params.mapColorBack=Qt::white;
     MapScheme->params.mapPath=map->params.mapPath;
     MapScheme->config.enableDrawBackground=1;
+    //work bad: MapScheme->config.enableKineticScroll=MapScheme->config.enableCaching;
     MapScheme->config.mapLastFile="";
     MapScheme->applyConfig();
 
-    if(MapScheme->config.enableCaching)
-    {
-     FlickCharm *fcharm=new FlickCharm(MapScheme);
-     fcharm->activateOn(MapScheme);
-     connect(fcharm,SIGNAL(started()),MapScheme,SLOT(mapStartDragging()));
-     connect(fcharm,SIGNAL(finished()),MapScheme,SLOT(mapStopDragging()));
-    }
-
     //MapScheme->setStyleSheet(TOOLBAR_STYLE.arg(Config.appIconSize));
 
     map->extractFiles(map->params.mapFile,FileName,map->params.mapPath);
@@ -659,6 +806,12 @@ void MainWindow::nodeInformation()
     MapScheme->verticalScrollBar()->setValue(MapScheme->verticalScrollBar()->maximum()/2);
     MapScheme->state.mapLoaded=1;
 
+    if(map->config.enableTranslit)
+    {
+     map->convertToTranslit(key);
+     key=key.replace("Skhema",tr("Schema"));
+    }
+
     Tabs->addTab(MapScheme,key);
     new TMobileUi(this,MapScheme,1);
     if(!MobileVersion)
@@ -688,7 +841,31 @@ void MainWindow::nodeInformation()
   }
  }
 
- if(Tabs->count()) DetailsWindow->showMaximized();
+ if(!Tabs->count())
+ {
+  showPageMap();
+  DetailsWindow->close();
+  return;
+ }
+
+ if(MobileVersion)
+ {
+  DetailsWindow->ui->buttonBox->setVisible(0);
+  connect(DetailsWindow,SIGNAL(showed()),this,SLOT(toFullScreen()));
+  connect(DetailsWindow->ui->bOK,SIGNAL(clicked()),this,SLOT(showPageMap()));
+  connect(DetailsWindow->ui->bOK,SIGNAL(clicked()),DetailsWindow,SLOT(close()));
+  ui->stackMain->addWidget(DetailsWindow);
+  ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
+ }
+ else
+ {
+  DetailsWindow->ui->bOK->setVisible(0);
+  //connect(DetailsWindow,SIGNAL(rejected()),this,SLOT(showPageMap()));
+  DetailsWindow->showMaximized();
+ }
+
+// if(Tabs->count())
+// MobileVersion==2 ? DetailsWindow->showFullScreen():DetailsWindow->showMaximized();
 
 //qDebug() << testTimer.elapsed();
 }
@@ -698,14 +875,16 @@ void MainWindow::closeEvent(QCloseEvent * e)
  if(!isVisible()) { e->accept(); return;} // FIX: double exec dont know why
  map->state.mapLoaded=0;
  if(ui->dock->isVisible()) Config.dockWidth=ui->dock->width();
- setVisible(0);
+ hide();
+ qApp->processEvents();
  QSettings ini(appConfigFile,QSettings::IniFormat);
  ini.setIniCodec(codePage);
  QString key;
  ini.beginGroup("Main");
+ ini.setValue("Version", VERSION);
  ini.setValue("WindowState", saveState().toHex());
  if(!MobileVersion) ini.setValue("WindowGeometry", saveGeometry().toHex());
- ini.setValue("MapLastFile",map->params.mapFile);
+ ini.setValue(IniKeyStr[ikMLastFile],map->params.mapFile);
  key="Locale";
  if(ini.contains(key))
   ini.setValue(key,Config.locale);
@@ -724,11 +903,31 @@ void MainWindow::closeEvent(QCloseEvent * e)
  if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(cachePath);
  else
  if(map->config.enableCaching && !QFile::exists(map->params.mapPath+".cache"))
-  map->CachedMap->save(map->params.mapPath+".cache","PNG");
+ {
+  QList<QByteArray> supportFormats;
+  supportFormats << QImageWriter::supportedImageFormats();
+  int supportCount=supportFormats.count();
+  if(supportCount)
+  {
+   QByteArray format;
+   format="png";
+   if(!supportFormats.contains(format))
+   {
+    format="jpg";
+    if(!supportFormats.contains(format)) format=supportFormats.at(0);
+   }
+   //QImage img = map->CachedMap->toImage();
+   QImageWriter imgWriter(map->params.mapPath+".cache",format.toUpper());
+   if(imgWriter.canWrite())
+        imgWriter.write(map->CachedMap->toImage());
+   else map->CachedMap->save(map->params.mapPath+".cache",format);
+  }
+ }
  map->clearMap();
 
  //setVisible(0);
  e->accept();
+ qApp->quit();
 }
 
 void applySettings(const IniSettingMap &settings)
@@ -787,6 +986,21 @@ void applySettings(const IniSettingMap &settings)
  if(map->config.enableCustomFont)
       map->params.nodeFont=nodeFont;
  else map->params.nodeFont=map->params.nodeFontDefault;
+ map->params.nodeTimeFont=map->params.nodeFont;
+ map->params.nodeTimeFont.setPixelSize(map->params.nodeWidth*1.15);
+
+ if(mainWnd->Config.mapKineticScrollCheck && map->config.enableCaching)
+ {
+  charm.activateOn(map);
+  mainWnd->connect(&charm,SIGNAL(started()),map,SLOT(mapStartDragging()));
+  mainWnd->connect(&charm,SIGNAL(finished()),map,SLOT(mapStopDragging()));
+ }
+ else
+ {
+  charm.deactivateFrom(map);
+  mainWnd->disconnect(&charm,SIGNAL(started()),map,SLOT(mapStartDragging()));
+  mainWnd->disconnect(&charm,SIGNAL(finished()),map,SLOT(mapStopDragging()));
+ }
 
 }
 
@@ -905,31 +1119,55 @@ qint64 sizeOfDir(const QString &DirName)
 void MainWindow::on_mAddMap_triggered()
 {
  QString MapPath=appPath+"map/";
- if(Config.locale!="ru")
-      QDesktopServices::openUrl(QUrl(URL_TRANSLATE.arg(Config.locale).arg(URL_MAPS)));
- else QDesktopServices::openUrl(QUrl(URL_MAPS));
- MapPath=QDir::toNativeSeparators(MapPath);
- QMessageBox::information(this,tr("Add maps"),tr("1. Wait until loaded site...\n2. Select map\n3. Save file map here:")+"\n     "+MapPath);
+ if(QMessageBox::information(this,tr("Add maps"),tr("1. Wait until loaded site...\n2. Select map\n3. Save file map here:")+"\n     "+MapPath))
+ {
+     if(Config.locale!="ru")
+         QDesktopServices::openUrl(QUrl(URL_TRANSLATE.arg(Config.locale).arg(URL_MAPS)));
+     else QDesktopServices::openUrl(QUrl(URL_MAPS));
+     MapPath=QDir::toNativeSeparators(MapPath);
+ }
 }
 
+void MainWindow::toFullScreen()
+{ ui->mFullScreen->setChecked(1); }
+
+void MainWindow::showPageLoading()
+{ ui->stackMain->setCurrentIndex(0); }
+
+void MainWindow::showPageMap()
+{ ui->stackMain->setCurrentIndex(1); }
 
 void MainWindow::on_mFullScreen_toggled(bool checked)
 {
  //bool b=windowState()!=Qt::WindowFullScreen;
- if(MobileVersion) ui->mExit->setVisible(checked);
+
+ if(MobileVersion)
+ {
+  ui->mExit->setVisible(checked); // menu (MobileUI - button in mobileui)
+#ifndef Q_WS_MAEMO_5
+  menuBar()->setVisible(!checked);
+#endif
+ }
  else (checked ? ui->toolBar->addAction(ui->mExit):ui->toolBar->removeAction(ui->mExit));
 
- if(checked) showFullScreen();
- else        showMaximized();
+#ifndef QML_EDITION
+ if(checked)
+       showFullScreen();
+  else showMaximized();
+#endif
+
 }
 
 void MainWindow::setScaleForUi(qreal UiScale)
 {
  if(UiScale<=qreal(0.0)) return;
-
+ //qDebug() << UiScale;
  QFont font=Config.appFont;
  Config.appIconSize=ICONSIZE*UiScale;
- font.setPointSizeF(font.pointSizeF()*UiScale);
+ if(font.pixelSize()>0)
+      font.setPixelSize(font.pixelSize()*UiScale);
+ else font.setPointSizeF(font.pointSizeF()*UiScale);
+
  qApp->setFont(font);
  if(MobileVersion && mUi)
       mUi->setToolbarIconSize(Config.appIconSize);
