@@ -40,7 +40,7 @@ public:
 
     QTextCodec *codePage;
     TMapView *map;
-    Settings *SettingWindow;
+    Settings *SettingsWindow;
 
     struct TConfig
     {
@@ -57,20 +57,21 @@ public:
      qreal appUiScale;
      int appIconSize;
      bool appFullscreen;
+     bool appFirstStart;
 
      QSize mainWindow;
      QSize settingWindow;
     };
     TConfig Config;
 
-    bool MobileVersion;
+    char MobileVersion;
+    Ui::MainWindow *ui;
     TMobileUi *mUi;
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event);
 
 private:
-    Ui::MainWindow *ui;
     void closeEvent(QCloseEvent * e);
 
     TCompleter *Completer;
@@ -82,6 +83,9 @@ public slots:
     void setNodeDefault(bool checked,TMapNode *Node=NULL);
     void loadNodeDefault();
     void checkNodeDefault();
+    void toFullScreen();
+    void showPageLoading();
+    void showPageMap();
 
 private slots:
 
@@ -98,7 +102,6 @@ private slots:
     void on_mExit_triggered();
     void setDelayNames(QStringList list);
     void nodeInformation();
-
 };
 
 #endif // MAINWINDOW_H
