@@ -18,6 +18,9 @@ public:
 public slots:
  void setToolbarIconSize(int Size);
 
+private slots:
+ void hideSearch(bool state);
+
 private:
  QToolButton* createButtonFromAction(QAction *Action,bool AutoRepeat=0);
 
@@ -27,7 +30,7 @@ private:
  QVBoxLayout *lLeft;
  QVBoxLayout *lRight;
 
- QLabel *textDescription;
+ QLabel *textInfo;
 
  QToolButton *bExit;
  QToolButton *bFullscreen;
@@ -35,9 +38,19 @@ private:
  QToolButton *bZoomOut;
  QToolButton *bZoomIn;
  QToolButton *bFit;
+ QToolButton *bClear;
+ QToolButton *bInfo;
 
  TMapView *MapView;
 
+ QWidget *Description;
+ QLabel *LabelInfo;
+ QTextBrowser *TextDesc;
+ QPushButton *bOK;
+
+protected:
+bool eventFilter(QObject *obj, QEvent *event);
+
 };
 
 #endif // MOBILEUI_H
