@@ -4,7 +4,8 @@
 #include <QColorDialog>
 #include <QFontDialog>
 #include <QSettings>
-
+#include <QShowEvent>
+#include <QPushButton>
 
 #include "settings.h"
 #include "mainwindow.h"
@@ -21,13 +22,42 @@ Settings::Settings(QWidget *parent) :
 {
  bool MobileVersion=mainWnd->MobileVersion;
  setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
-
  ui->setupUi(this);
- QFontMetrics fmWidth(font());
- int WindowWidth=fmWidth.width(ui->checkMFastScrolling->text())+50;
- setMinimumWidth(WindowWidth);
- setMaximumWidth(WindowWidth+50);
- resize(WindowWidth,WindowWidth*1.4);
+ if(!MobileVersion)
+ {
+  QFontMetrics fmWidth(font());
+  QList<QCheckBox *> checks =  findChildren<QCheckBox *>();
+  int WindowWidth=0;
+  foreach(QCheckBox *chk,checks)
+  {
+   int width=fmWidth.width(chk->text());
+   if(width>WindowWidth) WindowWidth=width;
+  }
+
+  setMinimumWidth(WindowWidth+50);
+  setMaximumWidth(WindowWidth+100);
+  resize(WindowWidth,WindowWidth*1.6);
+ }
+
+#ifdef Q_OS_SYMBIAN // QDialogButtonBox not supported - replaced QPushButton
+ ui->buttonBox->hide();
+ QHBoxLayout *HLayout = new QHBoxLayout;
+ QWidget *SoftKeysBar = new QWidget(this);
+ HLayout->setContentsMargins(0,10,0,0);
+ QPushButton *aSave = new QPushButton(ui->buttonBox->buttons().first()->text());
+ connect(aSave, SIGNAL(clicked()),this, SLOT(on_buttonBox_accepted()));
+ connect(aSave, SIGNAL(clicked()),this, SLOT(accept()));
+
+ QPushButton *aCancel = new QPushButton(ui->buttonBox->buttons().last()->text());
+ connect(aCancel, SIGNAL(clicked()),this, SLOT(on_buttonBox_rejected()));
+ connect(aCancel, SIGNAL(clicked()),this, SLOT(reject()));
+
+ HLayout->addWidget(aSave);
+ HLayout->addWidget(aCancel);
+ SoftKeysBar->setLayout(HLayout);
+ layout()->addWidget(SoftKeysBar);
+#endif
+
 #ifndef Q_WS_MAEMO_5
  QObjectList l = ui->toolBox->children();
  for (QObjectList::iterator it = l.begin(); it < l.end(); it++)
@@ -44,12 +74,13 @@ Settings::Settings(QWidget *parent) :
  ui->toolBox->setStyleSheet(ToolStyle.arg(fm.height()+1));
  ui->toolBox->setCurrentIndex(0);
  ui->gbFontStation->setVisible(0);
- ui->gbFontStation->setAttribute(Qt::WA_NoSystemBackground);;
+ ui->gbFontStation->setAttribute(Qt::WA_NoSystemBackground);
  updateLabelCacheSize();
  QString TextColor=tr("Color...");
  ui->bSBackColor->setText(TextColor);
  ui->bSShadowColor->setText(TextColor);
  ui->bMBackColor->setText(TextColor);
+ ui->buttonBox->setFocus();
 
  //if(!QFile::exists(appConfigFile)) saveSettings(changeSettings());
 
@@ -77,21 +108,35 @@ Settings::Settings(QWidget *parent) :
   connect(ui->checkWFullScreen,SIGNAL(clicked()),this,SLOT(changeSettings()));
 
   //connect(ui->checkMCleanCache,SIGNAL(clicked()),this,SLOT(changeSettings()));
+ }else // mobile
+ {
+  ui->checkMShowScrollbar->setVisible(0);
+  setAttribute(Qt::WA_DeleteOnClose);
  }
 
  connect(ui->spinUiScale,SIGNAL(valueChanged(int)),mainWnd,SLOT(setScaleForUi(int)));
+ //installEventFilter(this);
+ DefaultConfig=changeSettings();
+ loadSettings();
+ loadSettingsToUi(AppConfig);
 }
 
-void Settings::closeEvent(QCloseEvent * e)
+void Settings::showEvent(QShowEvent *e)
+{Q_UNUSED(e);
+ emit showed();
+}
+
+void Settings::closeEvent(QCloseEvent *e)
 {Q_UNUSED(e);
  applySettings(AppConfig);
- ((MainWindow*)parent())->SettingWindow=NULL;
- delete this;
+ //delete this;
+ //deleteLater();
 }
 
 Settings::~Settings()
 {
-    delete ui;
+ mainWnd->SettingsWindow=NULL;
+ delete ui;
 }
 
 void Settings::keyPressEvent(QKeyEvent *e)
@@ -130,8 +175,10 @@ QFont getFontFromLabel(QLabel *Label)
 
 void setFontToLabel(QLabel *Label,QFont &Font)
 {
- qreal Size=Font.pointSizeF();
- Font.setPointSizeF(Label->font().pointSizeF());
+ qreal Size=(Font.pointSizeF()==-1 ? Font.pixelSize():Font.pointSizeF());
+ if(Label->font().pointSizeF()==-1)
+      Font.setPixelSize(Label->font().pixelSize());
+ else Font.setPointSizeF(Label->font().pointSizeF());
  Label->setFont(Font);
  Label->setText(QString("%1, %2").arg(Font.family()).arg(Size));
 }
@@ -140,7 +187,7 @@ void Settings::on_bSFont_clicked()
 {
  bool ok;
  QFont NewFont;
- NewFont=QFontDialog::getFont(&ok,getFontFromLabel(ui->labelSFont),this);
+ NewFont=QFontDialog::getFont(&ok,getFontFromLabel(ui->labelSFont),0);
  if(ok)
   setFontToLabel(ui->labelSFont,NewFont);
 }
@@ -148,13 +195,22 @@ void Settings::on_bSFont_clicked()
 void Settings::on_buttonBox_accepted()
 {
   saveSettings(changeSettings());
+  emit closed();
 }
 
 void Settings::on_buttonBox_rejected()
 {
  applySettings(AppConfig);
- ((MainWindow*)parent())->SettingWindow=NULL;
- delete this;
+  emit closed();
+}
+
+void Settings::on_bDefaultConfig_clicked()
+{
+ loadSettingsToUi(DefaultConfig);
+ ui->spinUiScale->setValue(100);
+ ui->checkWFullScreen->setChecked(mainWnd->MobileVersion);
+ ui->checkMCaching->setChecked(mainWnd->MobileVersion);
+ if(!mainWnd->MobileVersion) changeSettings();
 }
 
 IniSettingMap Settings::changeSettings()
@@ -200,7 +256,8 @@ IniSettingMap Settings::changeSettings()
 
  return Setting;
 }
-void Settings::loadSettings(const IniSettingMap &set)
+
+void Settings::loadSettingsToUi(const IniSettingMap &set)
 {
  IniKeyMap key;
  QString value;
@@ -260,8 +317,10 @@ void Settings::loadSettings(const IniSettingMap &set)
  key=set.value(igMain);
  value=key.value(ikWFullScreen);
  if(!value.isEmpty()) ui->checkWFullScreen->setChecked(value.toInt());
- value=key.value(ikWUiScale);
- if(!value.isEmpty()) ui->spinUiScale->setValue(value.toFloat()*100);
+ else ui->checkWFullScreen->setChecked(mainWnd->Config.appFullscreen);
+ //value=key.value(ikWUiScale);
+ //if(!value.isEmpty())
+ ui->spinUiScale->setValue(mainWnd->Config.appUiScale*100);
 
  // [Other]
  value=set.value(igOther).value(ikMCleanCache);
@@ -289,3 +348,5 @@ void Settings::updateLabelCacheSize()
 
  ui->labelCacheSize->setText(QString("%1 %2").arg((Size-int(Size)>0 ? QString::number(Size,'f',2):QString::number(Size))).arg(Ext));
 }
+
+
