@@ -15,9 +15,10 @@ class Settings : public QDialog
 public:
     explicit Settings(QWidget *parent = 0);
     ~Settings();
-    void loadSettings(const IniSettingMap &set);
+    void loadSettingsToUi(const IniSettingMap &set);
 
     Ui::Settings *ui;
+    IniSettingMap DefaultConfig;
 
 private:
     void closeEvent(QCloseEvent * e);
@@ -27,6 +28,11 @@ private:
 
 protected:
     void keyPressEvent(QKeyEvent *e);
+    void showEvent(QShowEvent *e);
+
+signals:
+    void closed();
+    void showed();
 
 private slots:
 
@@ -41,6 +47,7 @@ private slots:
     IniSettingMap changeSettings();
 
 
+    void on_bDefaultConfig_clicked();
 };
 
 #endif // SETTINGS_H
